function [he hp hs] = plot_inv_result (varargin)

%-----------------------------------------
% Parameters

% Number of layer
cfg.ztop = 0.1;
cfg.zbot = 200;
cfg.nlay = 200;

% Sediment density
cfg.sdns = 2100;
cfg.rdns = 2700;

% Gradient type
cfg.gtyp = 'lin';

% Add top layer
cfg.tlck = 'y';
cfg.tpfl = '../Data/top_layer.ascii';

%-----------------------------------------
% Check for input file
if (nargin ~= 1)
  disp('Error: Model file not specified.');
  disp('Exit program...');
  return;
end

%-----------------------------------------
% Import configration
f01 = fopen(varargin{1});
if (f01 ~= -1)
  cfg = read_out_cfg(cfg,f01);
else
  disp('Error: cannot open configuration file.');
  disp('Exit program...');
  return;
end
fclose(f01);

%-----------------------------------------
% Generate parameters
par = gen_par(cfg);

%-----------------------------------------
% Create model
[hl vp vs dn] = gen_profile(cfg,par);

%-----------------------------------------
% Plot profile
figure(1); hold on;
set(gcf,'Color',[1 1 1]);
set(gcf,'Position',[550 200 250 450]);
set(gcf,'Renderer','zbuffer');

hp = plot_vl_color(hl,vp,[0.6 0.6 0.6]); hold on;
hs = plot_vl_color(hl,vs,[0 0 0]); hold off;
axis([0 5000 0 150]);

set(gca,'FontWeight','Bold','FontSize',10,'LineWidth',2);
set(gca,'TickDir','out');
xlabel('Velocity (m/s)');
ylabel('Depth (m)');

grid off;
box on;

return;
